@@ -7,7 +7,9 @@ import matplotlib.pyplot as plt
 import matplotlib.animation as animation
 from matplotlib import cm
 import math
-
+class Error(Exception):
+    """Base class for exceptions in this module."""
+    pass
 class Viz():
     f = None
     X  = None
@@ -80,8 +82,8 @@ class Viz():
             save: file name to save the animation
             show: show the animated figure in matplotlib window
         """
-        if len(self.best_hist) <=0 or len(self.middle_hist) <=0 or len(self.worst_hist):
-            raise('History is empty, make sure you set track=True in run() function')
+        if len(self.best_hist) <=0 or len(self.middle_hist) <=0 or len(self.worst_hist) <=0:
+            raise Error('History is empty, make sure you set track=True in run() function')
         fig = plt.figure(figsize=fig_size)
         ax = plt.axes(projection='3d')
         ax.contour3D(self.X, self.Y, self.Z, 50, cmap=cm.cool,alpha=0.3)
